@@ -53,55 +53,36 @@ Shipwright::Backend - Backend
 
 =head1 SYNOPSIS
 
-use Shipwright::Backend;
-$backend = Shipwright::Backend->new(repository => $args{repository});
+    # shipwright some_command -r backend_type:path
+    shipwright create -r svn:file:///svnrepo/shipwright/my_proj
+
+    use Shipwright::Backend;
+    $backend = Shipwright::Backend->new(repository => $args{repository});
+
+=head1 DESCRIPTION
+
+See <Shipwright::Manual::Glossary/repository> to understand concept. Look
+at list of </SUPPORTED BACKENDS> and L<IMPLEMENTING BACKENDS> if you want
+add a new one.
+
+=head1 SUPPORTED BACKENDS
+
+Currently, the supported backends are L<FS|Shipwright::BACKEND::FS>, L<Git|Shipwright::BACKEND::Git>, L<SVK|Shipwright::BACKEND::SVK> and L<SVN|Shipwright::BACKEND::SVN>.
+
+=head1 IMPLEMENTING BACKENDS
+
+Each implementation of a backend is a subclass of L<Shipwright::Backend::Base>.
 
 =head1 METHODS
 
-=over
+This is a tiny class with only one method C<new> that loads
+particular implementation class and returns instance of that
+class.
 
-=item new
+=head2 new repository => "type:path"
 
-returns the Backend object that corresponds to the type in
-$args{repository}.
-
-Currently, the supported backends are FS, SVN and SVK.
-
-=item initialize
-
-=item import
-
-=item export
-
-=item checkout
-
-=item commit
-
-=item update_order
-
-=item order
-
-=item map
-
-=item source
-
-=item delete
-
-=item info
-
-=item test_script
-
-=item requires
-
-=item flags
-
-=item version
-
-=item check_repository
-
-=item update
-
-=back
+Returns the backend object that corresponds to the type
+defined in the repository argument.
 
 =head1 AUTHORS
 
@@ -113,3 +94,5 @@ Shipwright is Copyright 2007-2009 Best Practical Solutions, LLC.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
+
+=cut
