@@ -68,6 +68,7 @@ sub initialize {
     $self->_install_module_build($dir);
     $self->_install_file_compare($dir);
     $self->_install_file_copy_recursive($dir);
+    $self->_install_file_path($dir);
 
     # set proper permissions for yml under /shipwright/
     my $sw_dir = catdir( $dir, 'shipwright' );
@@ -141,6 +142,15 @@ sub _install_file_copy_recursive {
       or confess "copy File/Copy/Recursive.pm failed: $!";
 }
 
+sub _install_file_path {
+    my $self = shift;
+    my $dir  = shift;
+
+    my $path = catdir( $dir, 'inc', 'File' );
+    rcopy( Module::Info->new_from_module('File::Path')->file, $path )
+      or confess "copy File/Path.pm failed: $!";
+}
+
 =item import
 
 import a dist.
